Crate astroimage

Crate astroimage 

Structs

AnalysisConfig
Builder configuration for analysis (internal).
AnalysisResult
Full analysis result for an image.
AnnotationConfig
Configuration for annotation rendering.
ImageAnalyzer
Image analyzer with builder pattern.
ImageConverter
ImageMetadata
ProcessedImage
StarAnnotation
Pre-computed annotation for one star, in output image coordinates.
StarMetrics
Quantitative metrics for a single detected star.
ThreadPool
Represents a user-created thread pool.
ThreadPoolBuilder
Used to create a new ThreadPool or to configure the global rayon thread pool.

Enums

BayerPattern
ColorScheme
Color scheme for star annotations.
FitMethod
Method used to measure this star’s PSF.
PixelData

Functions

annotate_image
Draw star annotations directly onto a ProcessedImage (RGB or RGBA).
compute_annotations
Compute annotation geometry for all detected stars, transformed to output coordinates.
create_annotation_layer
Rasterize annotations into a transparent RGBA buffer (same dimensions as output image).